import { jsxs as _jsxs } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _extends from "@babel/runtime/helpers/esm/extends";
import PropTypes from 'prop-types';
import cx from 'classnames';
import AtomIcon, { ATOM_ICON_COLORS, ATOM_ICON_SIZES } from '@s-ui/react-atom-icon';
import ActionButton from './ActionButton';
/**
 * Base class for the component
 */

var BASE_CLASS = 'sui-AtomActionButton';
/**
 * Available colors for the Action Button
 */

var COLORS = {
  PRIMARY: 'primary',
  ACCENT: 'accent',
  NEUTRAL: 'neutral'
};
/**
 * Available modifiers for the Action Button
 */

var MODIFIERS = {
  ACTIVE_FOCUSED: 'active',
  DISABLED: 'disabled',
  LINK: 'link'
};
/**
 * Available sizes for the Action Button
 */

var SIZES = {
  SMALL: 'small',
  MEDIUM: 'medium',
  LARGE: 'large'
};
/**
 * Available styles for the Action Button
 */

var STYLES = {
  FILLED_NEGATIVE: 'filledNegative',
  FILLED_POSITIVE: 'filledPositive',
  OUTLINE: 'outline',
  FLAT: 'flat'
};

var createClasses = function createClasses(array, sufix) {
  if (sufix === void 0) {
    sufix = '';
  }

  return array.reduce(function (res, key) {
    var _extends2;

    return _extends({}, res, (_extends2 = {}, _extends2[key] = BASE_CLASS + "--" + key + sufix, _extends2));
  }, {});
};

var CLASSES = createClasses([].concat(Object.values(SIZES), Object.values(STYLES), Object.values(MODIFIERS)));
var COLOR_CLASSES = createClasses([].concat(Object.values(COLORS)), 'Color');

var AtomActionButton = function AtomActionButton(props) {
  var children = props.children,
      className = props.className,
      _props$color = props.color,
      color = _props$color === void 0 ? COLORS.PRIMARY : _props$color,
      disabled = props.disabled,
      focused = props.focused,
      href = props.href,
      icon = props.icon,
      isButton = props.isButton,
      isSubmit = props.isSubmit,
      link = props.link,
      linkFactory = props.linkFactory,
      _props$size = props.size,
      size = _props$size === void 0 ? SIZES.MEDIUM : _props$size,
      _props$style = props.style,
      style = _props$style === void 0 ? STYLES.FILLED_NEGATIVE : _props$style,
      target = props.target,
      title = props.title,
      restProps = _objectWithoutPropertiesLoose(props, ["children", "className", "color", "disabled", "focused", "href", "icon", "isButton", "isSubmit", "link", "linkFactory", "size", "style", "target", "title"]);

  var classNames = cx(BASE_CLASS, COLOR_CLASSES[color], CLASSES[style], CLASSES[size], focused && CLASSES[MODIFIERS.ACTIVE_FOCUSED], disabled && CLASSES[MODIFIERS.DISABLED], link && CLASSES[MODIFIERS.LINK], className);

  var buttonProps = _extends({
    href: href,
    isButton: isButton,
    isSubmit: isSubmit,
    link: link,
    linkFactory: linkFactory,
    target: target,
    title: title
  }, restProps);

  return /*#__PURE__*/_jsxs(ActionButton, _extends({}, buttonProps, {
    className: classNames,
    children: [/*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-icon",
      children: /*#__PURE__*/_jsx(AtomIcon, {
        size: ATOM_ICON_SIZES.medium,
        color: ATOM_ICON_COLORS.currentColor,
        children: icon
      })
    }), /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS + "-text",
      children: children
    })]
  }));
};

AtomActionButton.displayName = 'AtomActionButton';
AtomActionButton.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Content to be included in the button
   */
  children: PropTypes.node,

  /**
   * Classes to add to button
   */
  className: PropTypes.any,

  /**
   * Color of button:
   * 'primary' (default),
   * 'accent',
   * 'neutral'
   */
  color: PropTypes.oneOf(Object.values(COLORS)),

  /**
   * Disabled: faded with no interaction.
   */
  disabled: PropTypes.bool,

  /**
   * Modifier: state of :active, :focus
   */
  focused: PropTypes.bool,

  /**
   * URL to be added on the HTML link
   */
  href: PropTypes.string,

  /**
   * Icon to be displayed (required)
   */
  icon: PropTypes.node.isRequired,

  /**
   * HTML element: if true, render a link. Otherwise render a button
   */
  link: PropTypes.bool,

  /**
   * Size of the icon
   * {SMALL: 'small',
   * MEDIUM: 'medium',
   * LARGE: 'large'}
   */
  size: PropTypes.oneOf(Object.values(SIZES)),

  /**
   * Style of the button: 'filledNegative' (default), 'filledPositive', 'outline', 'flat'
   */
  style: PropTypes.oneOf(Object.values(STYLES)),

  /**
   * Target to be added on the HTML link
   */
  target: PropTypes.string,

  /**
   * Title to be added on button or link
   */
  title: PropTypes.string,

  /**
   * Factory used to create navigation link
   */
  linkFactory: PropTypes.func,

  /**
   * if true, type="submit" (needed when several action buttons coexist under the same form)
   */
  isSubmit: PropTypes.bool,

  /**
   * if true, type="button" (needed when several action buttons coexist under the same form)
   */
  isButton: PropTypes.bool
} : {};
export default AtomActionButton;
export { COLORS as atomActionButtonColors };
export { SIZES as atomActionButtonSizes };
export { STYLES as atomActionButtonStyles };